MethodChannelMailTo class
Method-channel implementation of MailToPlatform.
- Inheritance
-
- Object
- PlatformInterface
- MailToPlatform
- MethodChannelMailTo
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
compose(
MailMessage message, {MailApp? app}) → Future< bool> -
Opens
app's compose screen prefilled withmessage.override -
installedApps(
) → Future< List< MailApp> > -
Mail apps installed on the device.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pickApp(
{String? title, String? cancelLabel, String? emptyMessage, String? okLabel, String? otherAppsLabel, bool showEmptyAlert = true, bool showOtherApps = true}) → Future< MailApp?> -
Shows the OS dialog listing installed mail apps and returns the pick,
or
nullwhen dismissed or when nothing is installed.override -
Opens the system share sheet with
message.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited