MailToPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • MailToPlatform
Implementers

Constructors

MailToPlatform()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

compose(MailMessage message, {MailApp? app}) Future<bool>
Opens app's compose screen prefilled with message.
installedApps() Future<List<MailApp>>
Mail apps installed on the device.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pickApp({String? title, String? cancelLabel, String? emptyMessage, String? okLabel, String? otherAppsLabel, bool showEmptyAlert = true, bool showOtherApps = true}) Future<MailApp?>
Shows the OS dialog listing installed mail apps and returns the pick, or null when dismissed or when nothing is installed.
share(MailMessage message, {ShareMetadata? metadata}) Future<bool>
Opens the system share sheet with message.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance MailToPlatform
getter/setter pair