pickApp method

Future<MailApp?> pickApp({
  1. String? title,
  2. String? cancelLabel,
  3. String? emptyMessage,
  4. String? okLabel,
  5. String? otherAppsLabel,
  6. bool showEmptyAlert = true,
  7. bool showOtherApps = true,
})

Shows the OS dialog listing installed mail apps and returns the pick, or null when dismissed or when nothing is installed.

Implementation

Future<MailApp?> pickApp({
  String? title,
  String? cancelLabel,
  String? emptyMessage,
  String? okLabel,
  String? otherAppsLabel,
  bool showEmptyAlert = true,
  bool showOtherApps = true,
}) {
  throw UnimplementedError('pickApp() has not been implemented.');
}