pickApp method
Shows the OS dialog listing installed mail apps and returns the pick,
or null when dismissed or when nothing is installed.
Implementation
Future<MailApp?> pickApp({
String? title,
String? cancelLabel,
String? emptyMessage,
String? okLabel,
String? otherAppsLabel,
bool showEmptyAlert = true,
bool showOtherApps = true,
}) {
throw UnimplementedError('pickApp() has not been implemented.');
}